@@ -3,6 +3,7 @@ use nxui::natives_and_messaging::{ADVANCED_WINDOWSTYLE_UTILITY, WINDOWSTYLE_NORM
 use nxui::window::{AdvancedOptions, Application, Frame, Attributes};
 
 fn main() {
+    nxui::initialize();
     let app = UtilityApplication::new();
     nxui::nxui::create_new_app(Box::new(app));
 }
@@ -28,6 +29,10 @@ impl Application for UtilityApplication {
         Attributes::new(WINDOWSTYLE_NORMAL, "Utility Window".to_string(),400, 675, 100, 100)
     }
 
+    fn is_child_window(&self) -> bool {
+        false
+    }
+
     fn advanced_options(&self) -> AdvancedOptions {
         AdvancedOptions::new(ADVANCED_WINDOWSTYLE_UTILITY)
     }
