@@ -1,12 +1,9 @@
 //! Used to store and read data.
 
-use std::{fs, io};
-use std::path::{Path, PathBuf};
+use std::fs;
+use std::path::PathBuf;
 use platform_dirs::AppDirs;
-use std::fs::File;
-use std::io::{Error,Write};
 
-#[derive(Clone)]
 pub struct Storage {
     app_dirs: AppDirs
 }
@@ -70,23 +67,4 @@ impl Storage {
     pub fn get_data_dir(self) -> PathBuf {
         self.app_dirs.data_dir
     }
-
-    /// Create Config directory
-    /// Win: C:\Users\AppData\Roaming\app_name\config
-    pub fn create_config_dir(&self) -> PathBuf {
-        let path = PathBuf::from(format!("{}/config",self.app_dirs.config_dir.to_str().unwrap()));
-        println!("{}",path.to_str().unwrap());
-        match path.exists() {
-            true => {
-
-            }
-            false => {
-                match fs::create_dir(path.clone()) {
-                    Err(e) => panic!("{}: {}", path.to_str().unwrap(), e),
-                    Ok(_) => 0,
-                };
-            }
-        }
-        path
-    }
 }
