@@ -105,11 +105,6 @@ pub const WINDOWSTYLE_NORMAL: windows_sys::Win32::UI::WindowsAndMessaging::WINDO
 #[cfg(windows)]
 /// A window with only a close button
 pub const WINDOWSTYLE_ONLYEXIT: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE = windows_sys::Win32::UI::WindowsAndMessaging::WS_SYSMENU;
-#[deprecated(since="0.9.2", note="This constant has been discontinued.")]
-#[cfg(windows)]
-/// Window with no caption
-pub const WINDOWSTYLE_NOCAPTION: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE = windows_sys::Win32::UI::WindowsAndMessaging::WS_CAPTION;
-
 
 #[cfg(unix)]
 /// Standard window
