@@ -4,6 +4,8 @@ use crate::io::storage::Storage;
 
 pub mod dialog;
 
+//default not found
+
 #[cfg(windows)]
 #[derive(Clone)]
 pub struct Frame {
@@ -242,7 +244,7 @@ impl Frame {
 impl Default for Frame {
     fn default() -> Self {
         Self {
-            handle: gtk::Window::default()
+            handle: gtk::Window::new(gtk::WindowType::Toplevel)
         }
     }
 }
@@ -304,8 +306,9 @@ pub trait Application {
     fn app_name(&self) -> String;
     /// Returns WindowAttributes.
     fn attributes(&self) -> Attributes;
-
-    #[cfg(feature="nxui-awc")]
+	
+	fn is_child_window(&self) -> bool;
+	
     fn advanced_options(&self) -> AdvancedOptions {
         AdvancedOptions::default()
     }
